@@ -4,6 +4,12 @@ from .timepoints import get_notes_by_period
 import numpy as np
 
 
+def add_instrument_back_pointer(midi_obj):
+    for instrument in midi_obj.instruments:
+        for note in instrument.notes:
+            note.instrument = instrument
+
+
 def get_heat_maps(midi_obj, n_bins=24, beat_resolution=480, rid_melody=False, min_pitch=0, max_pitch=127):
     notes = []
     for instrument in midi_obj.instruments:
